@@ -3,10 +3,10 @@ Renaming tests. This means search for usages.
 I always leave a little bit of space to add room for additions, because the
 results always contain position informations.
 """
-#< 4 (0,4), (3,0), (5,0), (17,0)
+#< 4 (0,4), (3,0), (5,0), (17,0), (12,4), (14,5), (15,0)
 def abc(): pass
 
-#< 0 (-3,4), (0,0), (2,0), (14,0)
+#< 0 (-3,4), (0,0), (2,0), (14,0), (9,4), (11,5), (12,0)
 abc.d.a.bsaasd.abc.d
 
 abc
@@ -20,7 +20,7 @@ if 1:
 else:
     (abc) = 
 abc = 
-#< (-17,4), (-14,0), (-12,0), (0,0)
+#< (-17,4), (-14,0), (-12,0), (0,0), (-2,0), (-3,5), (-5,4)
 abc
 
 abc = 5
@@ -83,17 +83,18 @@ import module_not_exists
 module_not_exists
 
 
-#< ('rename1', 1,0), (0,24), (3,0), (6,17), ('rename2', 4,5), (10,17), (13,17), ('imports', 70, 16)
+#< ('rename1', 1,0), (0,24), (3,0), (6,17), ('rename2', 4,5), (11,17), (14,17), ('imports', 72, 16)
 from import_tree import rename1
 
-#< (0,8), ('rename1',3,0), ('rename2',4,20), ('rename2',6,0), (3,32), (7,32), (4,0)
+#< (0,8), ('rename1',3,0), ('rename2',4,20), ('rename2',6,0), (3,32), (8,32), (5,0)
 rename1.abc
 
-#< (-3,8), ('rename1', 3,0), ('rename2', 4,20), ('rename2', 6,0), (0,32), (4,32), (1,0)
+#< (-3,8), ('rename1', 3,0), ('rename2', 4,20), ('rename2', 6,0), (0,32), (5,32), (2,0)
 from import_tree.rename1 import abc
+#< (-5,8), (-2,32), ('rename1', 3,0), ('rename2', 4,20), ('rename2', 6,0), (0,0), (3,32)
 abc
 
-#< 20 ('rename1', 1,0), ('rename2', 4,5), (-10,24), (-7,0), (-4,17), (0,17), (3,17), ('imports', 70, 16)
+#< 20 ('rename1', 1,0), ('rename2', 4,5), (-11,24), (-8,0), (-5,17), (0,17), (3,17), ('imports', 72, 16)
 from import_tree.rename1 import abc
 
 #< (0, 32),
@@ -273,3 +274,28 @@ _sre
 
 #< 0
 import undefined
+
+# -----------------
+# comprehensions
+# -----------------
+
+#< 0 (0,0), (2,12)
+x = 32
+#< 12 (-2,0), (0,12)
+[x for x in x]
+
+#< 0 (0,0), (2,1), (2,12)
+x = 32
+#< 12 (-2,0), (0,1), (0,12)
+[x for b in x]
+
+
+#< 1 (0,1), (0,7)
+[x for x in something]
+#< 7 (0,1), (0,7)
+[x for x in something]
+
+#< 1 (0,1), (0,10)
+{x:1 for  x in something}
+#< 10 (0,1), (0,10)
+{x:1 for  x in something}
